"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSiteEditorNavigationCommands = useSiteEditorNavigationCommands;
var _commands = require("@wordpress/commands");
var _i18n = require("@wordpress/i18n");
var _element = require("@wordpress/element");
var _data = require("@wordpress/data");
var _coreData = require("@wordpress/core-data");
var _icons = require("@wordpress/icons");
var _router = require("@wordpress/router");
var _url = require("@wordpress/url");
var _compose = require("@wordpress/compose");
var _hooks = require("./hooks");
var _lockUnlock = require("./lock-unlock");
var _orderEntityRecordsBySearch = require("./utils/order-entity-records-by-search");
/**
 * WordPress dependencies
 */

/**
 * Internal dependencies
 */

const {
  useHistory,
  useLocation
} = (0, _lockUnlock.unlock)(_router.privateApis);
const icons = {
  post: _icons.post,
  page: _icons.page,
  wp_template: _icons.layout,
  wp_template_part: _icons.symbolFilled
};
function useDebouncedValue(value) {
  const [debouncedValue, setDebouncedValue] = (0, _element.useState)('');
  const debounced = (0, _compose.useDebounce)(setDebouncedValue, 250);
  (0, _element.useEffect)(() => {
    debounced(value);
    return () => debounced.cancel();
  }, [debounced, value]);
  return debouncedValue;
}
const getNavigationCommandLoaderPerPostType = postType => function useNavigationCommandLoader({
  search
}) {
  const history = useHistory();
  const isBlockBasedTheme = (0, _hooks.useIsBlockBasedTheme)();
  const delayedSearch = useDebouncedValue(search);
  const {
    records,
    isLoading
  } = (0, _data.useSelect)(select => {
    if (!delayedSearch) {
      return {
        isLoading: false
      };
    }
    const query = {
      search: delayedSearch,
      per_page: 10,
      orderby: 'relevance',
      status: ['publish', 'future', 'draft', 'pending', 'private']
    };
    return {
      records: select(_coreData.store).getEntityRecords('postType', postType, query),
      isLoading: !select(_coreData.store).hasFinishedResolution('getEntityRecords', ['postType', postType, query])
    };
  }, [delayedSearch]);
  const commands = (0, _element.useMemo)(() => {
    return (records !== null && records !== void 0 ? records : []).map(record => {
      const command = {
        name: postType + '-' + record.id,
        searchLabel: record.title?.rendered + ' ' + record.id,
        label: record.title?.rendered ? record.title?.rendered : (0, _i18n.__)('(no title)'),
        icon: icons[postType]
      };
      if (postType === 'post' || postType === 'page' && !isBlockBasedTheme) {
        return {
          ...command,
          callback: ({
            close
          }) => {
            const args = {
              post: record.id,
              action: 'edit'
            };
            const targetUrl = (0, _url.addQueryArgs)('post.php', args);
            document.location = targetUrl;
            close();
          }
        };
      }
      const isSiteEditor = (0, _url.getPath)(window.location.href)?.includes('site-editor.php');
      const extraArgs = isSiteEditor ? {
        canvas: (0, _url.getQueryArg)(window.location.href, 'canvas')
      } : {};
      return {
        ...command,
        callback: ({
          close
        }) => {
          const args = {
            postType,
            postId: record.id,
            ...extraArgs
          };
          const targetUrl = (0, _url.addQueryArgs)('site-editor.php', args);
          if (isSiteEditor) {
            history.push(args);
          } else {
            document.location = targetUrl;
          }
          close();
        }
      };
    });
  }, [records, isBlockBasedTheme, history]);
  return {
    commands,
    isLoading
  };
};
const getNavigationCommandLoaderPerTemplate = templateType => function useNavigationCommandLoader({
  search
}) {
  const history = useHistory();
  const location = useLocation();
  const isPatternsPage = location?.params?.path === '/patterns' || location?.params?.postType === 'wp_block';
  const didAccessPatternsPage = !!location?.params?.didAccessPatternsPage;
  const isBlockBasedTheme = (0, _hooks.useIsBlockBasedTheme)();
  const {
    records,
    isLoading
  } = (0, _data.useSelect)(select => {
    const {
      getEntityRecords
    } = select(_coreData.store);
    const query = {
      per_page: -1
    };
    return {
      records: getEntityRecords('postType', templateType, query),
      isLoading: !select(_coreData.store).hasFinishedResolution('getEntityRecords', ['postType', templateType, query])
    };
  }, []);

  /*
   * wp_template and wp_template_part endpoints do not support per_page or orderby parameters.
   * We need to sort the results based on the search query to avoid removing relevant
   * records below using .slice().
   */
  const orderedRecords = (0, _element.useMemo)(() => {
    return (0, _orderEntityRecordsBySearch.orderEntityRecordsBySearch)(records, search).slice(0, 10);
  }, [records, search]);
  const commands = (0, _element.useMemo)(() => {
    if (!isBlockBasedTheme && !templateType === 'wp_template_part') {
      return [];
    }
    return orderedRecords.map(record => {
      const isSiteEditor = (0, _url.getPath)(window.location.href)?.includes('site-editor.php');
      const extraArgs = isSiteEditor ? {
        canvas: (0, _url.getQueryArg)(window.location.href, 'canvas')
      } : {};
      return {
        name: templateType + '-' + record.id,
        searchLabel: record.title?.rendered + ' ' + record.id,
        label: record.title?.rendered ? record.title?.rendered : (0, _i18n.__)('(no title)'),
        icon: icons[templateType],
        callback: ({
          close
        }) => {
          const args = {
            postType: templateType,
            postId: record.id,
            didAccessPatternsPage: !isBlockBasedTheme && (isPatternsPage || didAccessPatternsPage) ? 1 : undefined,
            ...extraArgs
          };
          const targetUrl = (0, _url.addQueryArgs)('site-editor.php', args);
          if (isSiteEditor) {
            history.push(args);
          } else {
            document.location = targetUrl;
          }
          close();
        }
      };
    });
  }, [isBlockBasedTheme, orderedRecords, history]);
  return {
    commands,
    isLoading
  };
};
const usePageNavigationCommandLoader = getNavigationCommandLoaderPerPostType('page');
const usePostNavigationCommandLoader = getNavigationCommandLoaderPerPostType('post');
const useTemplateNavigationCommandLoader = getNavigationCommandLoaderPerTemplate('wp_template');
const useTemplatePartNavigationCommandLoader = getNavigationCommandLoaderPerTemplate('wp_template_part');
function useSiteEditorBasicNavigationCommands() {
  const history = useHistory();
  const isSiteEditor = (0, _url.getPath)(window.location.href)?.includes('site-editor.php');
  const isTemplatesAccessible = (0, _hooks.useIsTemplatesAccessible)();
  const isBlockBasedTheme = (0, _hooks.useIsBlockBasedTheme)();
  const commands = (0, _element.useMemo)(() => {
    const result = [];
    if (!isTemplatesAccessible || !isBlockBasedTheme) {
      return result;
    }
    result.push({
      name: 'core/edit-site/open-navigation',
      label: (0, _i18n.__)('Navigation'),
      icon: _icons.navigation,
      callback: ({
        close
      }) => {
        const args = {
          path: '/navigation'
        };
        const targetUrl = (0, _url.addQueryArgs)('site-editor.php', args);
        if (isSiteEditor) {
          history.push(args);
        } else {
          document.location = targetUrl;
        }
        close();
      }
    });
    result.push({
      name: 'core/edit-site/open-styles',
      label: (0, _i18n.__)('Styles'),
      icon: _icons.styles,
      callback: ({
        close
      }) => {
        const args = {
          path: '/wp_global_styles'
        };
        const targetUrl = (0, _url.addQueryArgs)('site-editor.php', args);
        if (isSiteEditor) {
          history.push(args);
        } else {
          document.location = targetUrl;
        }
        close();
      }
    });
    result.push({
      name: 'core/edit-site/open-pages',
      label: (0, _i18n.__)('Pages'),
      icon: _icons.page,
      callback: ({
        close
      }) => {
        const args = {
          path: '/page'
        };
        const targetUrl = (0, _url.addQueryArgs)('site-editor.php', args);
        if (isSiteEditor) {
          history.push(args);
        } else {
          document.location = targetUrl;
        }
        close();
      }
    });
    result.push({
      name: 'core/edit-site/open-templates',
      label: (0, _i18n.__)('Templates'),
      icon: _icons.layout,
      callback: ({
        close
      }) => {
        const args = {
          path: '/wp_template'
        };
        const targetUrl = (0, _url.addQueryArgs)('site-editor.php', args);
        if (isSiteEditor) {
          history.push(args);
        } else {
          document.location = targetUrl;
        }
        close();
      }
    });
    return result;
  }, [history, isSiteEditor, isTemplatesAccessible, isBlockBasedTheme]);
  return {
    commands,
    isLoading: false
  };
}
function useSiteEditorNavigationCommands() {
  (0, _commands.useCommandLoader)({
    name: 'core/edit-site/navigate-pages',
    hook: usePageNavigationCommandLoader
  });
  (0, _commands.useCommandLoader)({
    name: 'core/edit-site/navigate-posts',
    hook: usePostNavigationCommandLoader
  });
  (0, _commands.useCommandLoader)({
    name: 'core/edit-site/navigate-templates',
    hook: useTemplateNavigationCommandLoader
  });
  (0, _commands.useCommandLoader)({
    name: 'core/edit-site/navigate-template-parts',
    hook: useTemplatePartNavigationCommandLoader
  });
  (0, _commands.useCommandLoader)({
    name: 'core/edit-site/basic-navigation',
    hook: useSiteEditorBasicNavigationCommands,
    context: 'site-editor'
  });
}
//# sourceMappingURL=site-editor-navigation-commands.js.map